diff --git a/experiments/jobscripts/generators/mnist.sh b/experiments/jobscripts/generators/mnist.sh
index ef0180fe4be2e20d0310b8d85e7f360693c5f66b..4c79e8b10ada123e04f46c068cb346b20209f672 100644
--- a/experiments/jobscripts/generators/mnist.sh
+++ b/experiments/jobscripts/generators/mnist.sh
@@ -1,14 +1,16 @@
 #!/bin/bash
 
 #SBATCH --job-name="MNIST (ECCCo)"
-#SBATCH --time=10:00:00
-#SBATCH --ntasks=1000
-#SBATCH --cpus-per-task=1
+#SBATCH --time=05:00:00
+#SBATCH --ntasks=40
+#SBATCH --cpus-per-task=10
 #SBATCH --partition=compute
-#SBATCH --mem-per-cpu=8GB
+#SBATCH --mem-per-cpu=10GB
 #SBATCH --account=research-eemcs-insy
 #SBATCH --mail-type=END     # Set mail type to 'END' to receive a mail when the job finishes. 
 
 module load 2023r1 openmpi
 
-srun julia --project=experiments experiments/run_experiments.jl -- data=mnist output_path=results mpi > experiments/mnist.log
+source experiments/slurm_header.sh
+
+srun julia --project=experiments --threads $SLURM_CPUS_PER_TASK experiments/run_experiments.jl -- data=mnist output_path=results mpi threaded n_individuals=50 n_runs=10 > experiments/logs/mnist.log
diff --git a/experiments/jobscripts/generators/fmnist.sh b/experiments/jobscripts/generators/fmnist.sh
index 10504108e1139ff41a93481a1ebc02bdfea5a83d..b4ea63f1b119947e7f96f53b398a1977d4a8f66c 100644
--- a/experiments/jobscripts/generators/fmnist.sh
+++ b/experiments/jobscripts/generators/fmnist.sh
@@ -1,14 +1,16 @@
 #!/bin/bash
 
 #SBATCH --job-name="Fashion-MNIST (ECCCo)"
 #SBATCH --time=10:00:00
 #SBATCH --ntasks=1000
 #SBATCH --cpus-per-task=1
 #SBATCH --partition=compute
-#SBATCH --mem-per-cpu=8GB
+#SBATCH --mem-per-cpu=10GB
 #SBATCH --account=research-eemcs-insy
 #SBATCH --mail-type=END     # Set mail type to 'END' to receive a mail when the job finishes. 
 
 module load 2023r1 openmpi
 
-srun julia --project=experiments experiments/run_experiments.jl -- data=fmnist retrain output_path=results threaded mpi > experiments/fmnist.log
+source experiments/slurm_header.sh
+
+srun julia --project=experiments --threads $SLURM_CPUS_PER_TASK experiments/run_experiments.jl -- data=fmnist output_path=results mpi threaded n_individuals=50 n_runs=10 > experiments/logs/fmnist.log
@@ -1,14 +1,16 @@
 #!/bin/bash
 
-#SBATCH --job-name="Fashion-MNIST (ECCCo)"
-#SBATCH --time=10:00:00
-#SBATCH --ntasks=1000
-#SBATCH --cpus-per-task=1
+#SBATCH --job-name="Fashion MNIST (ECCCo)"
+#SBATCH --time=05:00:00
+#SBATCH --ntasks=40
+#SBATCH --cpus-per-task=10
 #SBATCH --partition=compute